#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys
import math
import time

from . import common
from . import constant
from . import register
from ..common.registerRW import RegisterRW

from ... import num


class Config(RegisterRW):
	
	###############################################
	MAX_CHANNELS  = constant.CHANNEL_MAX		#MAX CH
	OFFSET_REG2CH = 0x0100	#

	########## target register list ##########
	#target register list(common)
	TARGET_REGISTER_LIST_CMN = [
		"MOD", "MMD", #"MTM",
		"SPB", "ARS", "TGC", "TGE",
		"FRN", "FIT",
		"WTP",
	]

	#target register list(CH)
	TARGET_REGISTER_LIST_CHN = [
		"AFS", "GSL", "RJT", "POL",
		"CCF", "CDL", "CWK", "CTH",
		"CLD", "CUD", "FLK", "EPD",
		"PTS", "WSL", "LIG", "LIT",
		"TTY", "FST", "FSP", "QIR", "WAS",
	]

	###############################################
	SSP = constant.REG_SSP_500M		#500MHz

	###############################################
	def __init__(self, rbcp = None):
		super(Config, self).__init__(rbcp)
		self.__initializing(False)

		self.mRegisterAttribute = register.Register()
		self.createRegisterInfo(self.mTARGET_REGISTER_LIST, self.mRegisterAttribute)
	
	###############################################
	def __initializing(self, runParent = False):
		if runParent == True:
			super(Config, self)._RegisterRW__initializing()
		
		self.clearStatus()
	
	###############################################
	def clearStatus(self):
		super(Config, self).clearStatus()

	###############################################
	def runCalibration(self, wait_sec = 3.0, ipaddr = None, port = None):
		result = self.writeRegisterNtimes('ACS', [0, 1, 0], 0, ipaddr, port)	#ADC calibration
		if result == True: time.sleep(wait_sec)
		return result

	###############################################
	def isCommonRegister(self, name):
		return (self.mTARGET_REGISTER_LIST_CMN.count(name) > 0)
	
	###############################################
	def isChannelRegister(self, name):
		return (self.mTARGET_REGISTER_LIST_CHN.count(name) > 0)

	###############################################
	def startAcquisition(self, ipaddr = None, port = None):
		reg_stat = [constant.REG_AQS_STOP, constant.REG_AQS_START]
		result = self.writeRegisterNtimes("AQS", reg_stat, 0, ipaddr, port)
		return result

	###############################################
	def stopAcquisition(self, ipaddr = None, port = None):
		result = self.writeRegisterNtimes("AQS", [constant.REG_AQS_STOP], 0, ipaddr, port)
		return result

	###############################################
	def clearAcquisitionData(self, ipaddr = None, port = None):
		reg_stat = [constant.REG_CLR_LOW, constant.REG_CLR_HIGH, constant.REG_CLR_LOW]
		result = self.writeRegisterNtimes("CLR", reg_stat, 0, ipaddr, port)
		return result

	###############################################
	def setAcquisitionMode(self, value = constant.REG_MOD_HIST, ipaddr = None, port = None):
		result = self.writeRegisterByName("MOD", value, ipaddr, port)
		return result

	###############################################
	def setAcquisitionTimeMode(self, value = constant.REG_MMD_REALTIME, ipaddr = None, port = None):
		result = self.writeRegisterByName("MMD", value, ipaddr, port)
		return result

	###############################################
	def setAcquisitionTime(self, seconds, ipaddr = None, port = None):
		value = common.calcSeconds2Digit(seconds)
		result = self.writeRegisterByName("MTM", value, ipaddr, port)
		return result

	###############################################
	def getAcquisitionTime(self, ipaddr = None, port = None):
		value = self.readStatus("MTM", ipaddr, port)
		result = common.calcDigit2Seconds(value)
		self.mStatus["MTM",] = value
		return result

	###############################################
	@staticmethod
	def toDigitARS(value):
		value0 = int(256 * (2 ** value))
		digit = num.bitconverter.inRangeAndCoarce(value0, 256, 256)
		return digit

	###############################################
	@staticmethod
	def toDigitEPD(mv):
		#mv0 = float(num.bitconverter.inRangeAndCoarce(mv, constant.REG_EPD_MINMV, constant.REG_EPD_MAXMV))
		#mv1 = (-mv + 1000.0) / 2000.0 * 4000.0
		mv0 = (-mv + 1000.0) / 2000.0 * 4095.0
		mv1 = round(mv0)
		return int(mv1)

	###############################################
	"""
	@staticmethod
	def toDigitWSL(ssp, wch, wty):
		__wch = [0, 0]
		if ssp == constant.REG_SSP_1G:
			__wch[0]  =int((wch * 2) + constant.REG_WSL_1ST)
			__wch[1] = int((wch * 2) + constant.REG_WSL_LAST)
		
		digit1 = ((__wch[0] << 8) & 0x0000ff00) | wty
		digit2 = ((__wch[1] << 8) & 0x0000ff00) | wty

		return digit1, digit2
	"""
	@staticmethod
	def toDigitWSL(wch, wty):
		__wch = [0, 0]
		digit1 = ((__wch[0] << 8) & 0x0000ff00) | wty
		digit2 = ((__wch[1] << 8) & 0x0000ff00) | wty
		return digit1, digit2

	###############################################
	"""
	@staticmethod
	def toDigitWTP(wtp, wcp, ssp):
		if wcp == constant.REG_WCP_1_1: x = wtp
		else: x = (2 ** wcp) * 2

		if ssp == REG_SSP_1G: value = (x / 8) + 4
		else: value = (x / 4) + 4

		return int(value)
	"""
	@staticmethod
	def toDigitWTP(wtp):
		value = (wtp / 4) + 4		#500MHz
		return int(value)

	###############################################
	@staticmethod
	def toDigitQIR(nsec):
		digit = common.calcNanoseconds2Digit(nsec)
		return digit
	

