#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys


############################################################
TIME_DIGIT2NANOSEC = 8      #8ns/digit
CHANNEL_MAX     = 8         #8CH

LISTDATA_BLKBYTES = 10
REGADDR_CHUNIT  = 0x0100     


############################################################
##### common register ######################################
############################################################
########### common paramter ###########
##### MOD: measurement mode #####
REG_MOD_HIST = 0			#histogram
REG_MOD_WAVE = 1			#wave
REG_MOD_LIST = 2			#list
REG_MOD_LIST_PILEUP = 3		#list pileup
REG_MOD_LIST_COMMON = 4		#list common

##### MMD: measurement time mode #####
REG_MMD_REALTIME = 0
REG_MMD_LIVETIME = 1

##### AQS: acquisition start / stop #####
REG_AQS_STOP  = 0
REG_AQS_START = 1

##### CLR: clear #####
REG_CLR_LOW  = 0
REG_CLR_HIGH = 1

##### SPB: sampling bit #####
REG_SPB_14BIT = 0
REG_SPB_12BIT = 1

##### ARS: ADC read size #####
REG_ARS_256 = 0		#256byte
REG_ARS_512 = 1		#256byte
REG_ARS_01K = 2		#1024byte
REG_ARS_02K = 3		#2048byte
REG_ARS_04K = 4		#4096byte

##### TGC: trigger CH #####
REG_TGC_SIG1 = 1	#
REG_TGC_SIG2 = 2	#
REG_TGC_SIG3 = 4	#

##### TGE: trigger edge #####
REG_TGE_NEG = 0		#negative
REG_TGE_POS = 1		#positive

##### FRN: wave free run #####
REG_FRN_DISABLE = 0		#disable
REG_FRN_ENABLE  = 1		#enable

##### FIT: calc FIFO IRQ trigger #####
REG_FIT_MIN = 0x0000	#minimum value
REG_FIT_MAX = 0xffff	#maximum value
REG_FIT_DEFAULT = 0		#default value

##### DMD: TDC timing type #####
REG_DMD_CFD = 0		#
REG_DMD_LED = 1		#leading edge

##### IRG: TAC integral range #####
REG_IRG_DEFAULT = 0		#default value

##### WTP: wave trigger point #####
REG_WTP_MIN =  10	#minimum value
REG_WTP_MAX = 510	#maximum value

##### WTP: wave compress #####
REG_WCP_1_1   = 0	# 1/1
REG_WCP_1_4   = 1	# 1/4
REG_WCP_1_8   = 2	# 1/8
REG_WCP_1_16  = 3	# 1/16
REG_WCP_1_32  = 4	# 1/32
REG_WCP_1_64  = 5	# 1/64
REG_WCP_1_128 = 6	# 1/128
REG_WCP_1_256 = 7	# 1/256


###################################
########### CH paramter ###########
###################################
##### AFS: QDC full scale #####
REG_AFS_1_1   = 0	# 1/1
REG_AFS_1_2   = 1	# 1/2
REG_AFS_1_4   = 2	# 1/4
REG_AFS_1_8   = 3	# 1/8
REG_AFS_1_16  = 4	# 1/16
REG_AFS_1_32  = 5	# 1/32
REG_AFS_1_64  = 6	# 1/64
REG_AFS_1_128 = 7	# 1/128
REG_AFS_1_256 = 8	# 1/256
REG_AFS_1_512 = 9	# 1/512

##### GSL: analog gain #####
REG_GSL_X3 = 0	# 3 times
REG_GSL_X1 = 1	# 1 times

##### RJT: raise judge threshold #####
REG_RJT_MIN =     0		#minimum value(digit)
REG_RJT_MAX = 16383		#maximum value(digit)

##### POL: polarity #####
REG_POL_NEG = 0		# negative
REG_POL_POS = 1		# positive

##### CCF: CFD function #####
REG_CCF_X0_03 =  1	# 0.03 times
REG_CCF_X0_06 =  2	# 0.06 times
REG_CCF_X0_09 =  3	# 0.09 times
REG_CCF_X0_12 =  4	# 0.12 times
REG_CCF_X0_15 =  5	# 0.15 times
REG_CCF_X0_18 =  6	# 0.18 times
REG_CCF_X0_21 =  7	# 0.21 times
REG_CCF_X0_25 =  8	# 0.25 times
REG_CCF_X0_28 =  9	# 0.28 times
REG_CCF_X0_31 = 10	# 0.31 times
REG_CCF_X0_34 = 11	# 0.34 times
REG_CCF_X0_37 = 12	# 0.37 times
REG_CCF_X0_40 = 13	# 0.40 times
REG_CCF_X0_43 = 14	# 0.43 times
REG_CCF_X0_46 = 15	# 0.46 times

##### CDL: CFD delay #####
REG_CDL_02NS = 0	#  2 nsec
REG_CDL_04NS = 1	#  4 nsec
REG_CDL_06NS = 2	#  6 nsec
REG_CDL_08NS = 3	#  8 nsec
REG_CDL_10NS = 4	# 10 nsec
REG_CDL_12NS = 5	# 12 nsec
REG_CDL_14NS = 6	# 14 nsec
REG_CDL_16NS = 7	# 16 nsec

##### CWK: CFD walk #####
REG_CWK_MIN =    0	#minimum value
REG_CWK_MAX = 1023	#maximum value

##### CTH: CFD threshold #####
REG_CTH_MIN =    0	#minimum value
REG_CTH_MAX = 8192	#maximum value

##### CLD: QDC lower level discrimination #####
REG_CLD_MIN =    0	#minimum value
REG_CLD_MAX = 8191	#maximum value

##### CUD: QDC upeer level discrimination #####
REG_CUD_MIN =    0	#minimum value
REG_CUD_MAX = 8191	#maximum value

##### FLK: baseline restorer filter #####
REG_FLK_EXT   = 0	#
REG_FLK_FAST  = 1	#
REG_FLK_4US   = 2	#4usec
REG_FLK_85US  = 3	#85usec
REG_FLK_129US = 4	#129usec
REG_FLK_260US = 5	#260usec

##### EPD: analog offset #####
REG_EPD_MINMV = -1000.0		#minimum value(mv)
REG_EPD_MAXMV =  1000.0		#maximum value(mv)

##### PWE: ADC parameter write enable #####
REG_PWE_DISABLE = 0		#disable
REG_PWE_ENABLE  = 1		#enable

##### P0W: ADC coarse offset 1 #####
##### P1W: ADC coarse offset 2 #####
##### P2W: ADC fine offset 1 #####
##### P3W: ADC fine offset 2 #####
##### P4W: ADC coarse gain 1 #####
##### P5W: ADC coarse gain 2 #####
##### P6W: ADC middle gain 1 #####
##### P7W: ADC middle gain 2 #####


##### PTS: QDC pre-trigger #####
REG_PTS_P00NS = 0	#  0 nsec
REG_PTS_P08NS = 1	#- 8 nsec
REG_PTS_P16NS = 2	#-16 nsec
REG_PTS_P24NS = 3	#-24 nsec
REG_PTS_P32NS = 4	#-32 nsec
REG_PTS_P40NS = 5	#-40 nsec
REG_PTS_P48NS = 6	#-48 nsec
REG_PTS_P56NS = 7	#-56 nsec
REG_PTS_P64NS = 8	#-64 nsec

##### (SSP): select sampling #####
REG_SSP_500M = 0	#500M Hz
REG_SSP_1G   = 1	#1G Hz

##### WCH: wave CH #####
REG_WCH_CH1 = 0		#
REG_WCH_CH2 = 1		#
REG_WCH_CH3 = 2		#
REG_WCH_CH4 = 3		#
REG_WCH_CH5 = 4		#
REG_WCH_CH6 = 5		#
REG_WCH_CH7 = 6		#
REG_WCH_CH8 = 7		#

##### WTY: wave type #####
REG_WTY_RAW = 0		#
REG_WTY_CFD = 1		#
REG_WTY_FIL = 2		#filter
REG_WTY_PTG = 3		#

##### WSL: wave select #####
REG_WSL_1ST  = 0
REG_WSL_LAST = 1

##### LIG: QDC filter(ns) #####
REG_LIG_EXT   = 0	#
REG_LIG_10NS  = 1	#10 nsec
REG_LIG_20NS  = 2	#20 nsec
REG_LIG_50NS  = 3	#50 nsec
REG_LIG_100NS = 4	#100 nsec
REG_LIG_200NS = 5	#200 nsec

##### LIT: QDC select #####
REG_LIT_PEAK = 0	#
REG_LIT_SUM  = 1	#

##### TTY: timing type #####
REG_TTY_CFD = 0		#CFD
REG_TTY_LE  = 1		#leading edge

##### FST: FRC start count #####
##### FSP: FRC stop  count #####

##### QIR: QDC integral range #####
REG_QIR_MIN =   48	#minimum value
REG_QIR_MAX = 4000	#maximum value

##### WAS: input signal type #####
REG_WAS_NORMALSIG = 0	#normal
REG_WAS_FASTSIG   = 1	#fast
