#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys

from . import common
from . import constant
from . import register
from ..common.registerRW import RegisterRW


class Status(RegisterRW):
	
	###############################################
	MAX_CHANNELS  = constant.CHANNEL_MAX		#MAX CH
	OFFSET_REG2CH = 0x0100	#

	#target register list (common)
	TARGET_REGISTER_LIST_CMN = [
		"AQS", "RLT",
	]

	#target register list (CH)
	TARGET_REGISTER_LIST_CHN = [
		"ICT", "ICR", "TCT", "TCR",
		"LVT", "DDT",
	]

	###############################################
	def __init__(self, rbcp = None):
		self.mMaxChannel = constant.CHANNEL_MAX
		super(Status, self).__init__(rbcp)
		self.__initializing(False)

		self.mRegisterAttribute = register.Register()
		self.createRegisterInfo(self.mTARGET_REGISTER_LIST, self.mRegisterAttribute)
	
	###############################################
	def __initializing(self, runParent = False):
		if runParent == True:
			super(Status, self)._RegisterRW__initializing()
		self.clearStatus()

	###############################################
	def clearStatus(self):
		super(Status, self).clearStatus()

		for name in self.mTARGET_REGISTER_LIST_CHN:
			self.mStatus[name,] = [ 0 for n in range(self.mMaxChannel) ]
	
	###############################################
	def getElapsedSeconds(self, runDeviceRead = False, ipaddr = None, port = None):
		
		secElapsed = None

		if runDeviceRead == True: value = self.readStatus("RLT", ipaddr, port)
		else: value = self.getStatus("RLT")

		if not value is None:
			secElapsed = common.calcDigit2Seconds(value)

		return secElapsed

	###############################################
	def getElapsedMiiliSeconds(self, runDeviceRead = False, ipaddr = None, port = None):

		msec = None
		sec = self.getElapsedSeconds(runDeviceRead, ipaddr, port)

		if sec is not None:
			msec = int(sec * 1000.0)

		return msec

	###############################################
	#The status refers to the raed-only register, so writing is not possible.
	#When writing is executed, an exception will be thrown.
	def writeStatus(self, name = None, value = None, ipaddr = None, port = None):
		raise Exception('You cannot write to the status register.')

	###############################################
	#The status refers to the raed-only register, so writing is not possible.
	#When writing is executed, an exception will be thrown.
	def writeStatusAll(self, ipaddr = None, port = None):
		raise Exception('You cannot write to the status register.')


	
