#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys
import time

from ...sitcp import constant


class RegisterRW(object):
	
	###############################################
	MAX_CHANNELS  = 1		#MAX CH
	OFFSET_REG2CH = 0x0002	#

	########## target register list ##########
	#target register list(common)
	TARGET_REGISTER_LIST_CMN = []

	#target register list(CH)
	TARGET_REGISTER_LIST_CHN = []

	###############################################
	def __init__(self, rbcp = None):
		self.mTARGET_REGISTER_LIST_CMN = self.__class__.TARGET_REGISTER_LIST_CMN	#target register list(common)
		self.mTARGET_REGISTER_LIST_CHN = self.__class__.TARGET_REGISTER_LIST_CHN	#target register list(CH)
		self.mTARGET_REGISTER_LIST = self.mTARGET_REGISTER_LIST_CMN + self.mTARGET_REGISTER_LIST_CHN	#all

		self.__initializing()
		self.mRBCP = rbcp
	
	###############################################
	def __initializing(self):

		self.mRBCP = None
		self.mDestPort = None
		self.mDestIpaddr = None
		self.mLastException = None

		self.mStatus = {}
		self.mRegAttribute = None
		self.mListTargetRegister = []

	###############################################
	def isExistRegister(self, name):
		counts = self.mListTargetRegister.count(name)
		return (counts > 0)

	###############################################
	def createRegisterInfo(self, reglist_target, reg_attb):
		self.mRegAttribute = reg_attb
		self.mListTargetRegister = reglist_target
		self.clearStatus()

	###############################################
	def clearStatus(self):
		self.mStatus = {}

		for name in self.mTARGET_REGISTER_LIST_CMN:
			self.mStatus[name,] = 0
		for name in self.mTARGET_REGISTER_LIST_CHN:
			self.mStatus[name,] = [ 0 for n in range(self.MAX_CHANNELS) ]
		return

	###############################################
	def getStatus(self, name):
		return self.mStatus[(name,)]

	###############################################
	def setStatus(self, name, value):
		self.mStatus[(name,)] = value

	###############################################
	def setRBCP(self, rbcp):
		self.mRBCP = rbcp

	###############################################
	def setDestination(self, ipaddr, port = constant.DEFAULT_DEST_PORT):
		self.mDestPort = port
		self.mDestIpaddr = ipaddr

	###############################################
	def getAttribute(self, name):
		return self.mRegAttribute.getAttribute(name)

	###############################################
	def getDestAddress(self, ipaddr, port):
		
		work1, work2 = self.mRBCP.getDestAddress(ipaddr, port)
		destipaddr = ipaddr if not ipaddr is None else work1
		destport   = port   if not port   is None else work2

		return	destipaddr, destport

	###############################################
	def readRegisterByName(self, name, ipaddr = None, port = None):
		reg_attb = self.getAttribute(name)
		value = self.mRBCP.readNbytes(reg_attb.mAddress, reg_attb.mBytes, ipaddr, port)
		return value
		
	###############################################
	def readRegisterSignedByName(self, name, ipaddr = None, port = None):
		reg_attb = self.getAttribute(name)
		value = self.mRBCP.readNbytesSigned(reg_attb.mAddress, reg_attb.mBytes, ipaddr, port)
		return value

	###############################################
	def writeRegisterByName(self, name, value, ipaddr = None, port = None):
		reg_attb = self.getAttribute(name)
		result = self.mRBCP.writeNbytes(reg_attb.mAddress, value, reg_attb.mBytes, ipaddr, port)
		return result

	###############################################
	def writeRegisterNtimes(self, name, value_list, intervalms = 0, ipaddr = None, port = None):

		waittm = float(intervalms) / 1000.0		# --> seconds

		for i in range(len(value_list)):
			result = self.writeRegisterByName(name, value_list[i], ipaddr, port)
			if result != True: break
			if waittm > 0.0: time.sleep(waittm)
			
		return result

	###############################################
	def readStatus(self, name, ipaddr = None, port = None):

		value = None

		try:
			attb = self.mRegAttribute.getAttribute(name)
			wvalue0 = self.mStatus[name,]

			if isinstance(wvalue0, list) == True:	#list type
				value = []

				for i in range(len(wvalue0)):
					address = attb.mAddress + (i * self.OFFSET_REG2CH)
					wvalue = self.mRBCP.readNbytes(address, attb.mBytes, ipaddr, port)
					#print ("[R] %s:%d, 0x%08x: 0x%04x(%d)" % (name, i, address, wvalue, wvalue))	#
					if wvalue is None: break

					value.append(wvalue)
			else:
				value = self.mRBCP.readNbytes(attb.mAddress, attb.mBytes, ipaddr, port)
				#print ("[R] %s, 0x%08x: 0x%04x(%d)" % (name, attb.mAddress, value, value))	#
		except Exception as ex:
			self.mLastException = ex
			raise ex	#raise exception

		return value


	###############################################
	def readStatusAll(self, ipaddr = None, port = None):

		result = True

		for name, in self.mStatus.keys():
			value = self.readStatus(name, ipaddr, port)
			self.mStatus[name,] = value

			if value is None:
				result = False
				break
		
		return result

	###############################################
	def writeStatus(self, name, value, ipaddr = None, port = None):

		result = True

		try:
			attb = self.mRegAttribute.getAttribute(name)

			if isinstance(value, list) == True:	valueList = value	#list type (CH register)
			else: valueList = [value]								##single variable (common register)

			for i in range(len(valueList)):
				address = attb.mAddress + (i * self.OFFSET_REG2CH)
				result = self.mRBCP.writeNbytes(address, valueList[i], attb.mBytes, ipaddr, port)
				#print ("[W] %s:%d, 0x%08x(%d): 0x%04x(%d)" % (name, i, address, attb.mBytes, valueList[i], valueList[i]))	#
				if result != True: break
		except Exception as ex:
			self.mLastException = ex
			result = False
			raise ex
		
		return	result

	
	###############################################
	def writeStatusAll(self, ipaddr = None, port = None):

		result = True

		for name, in self.mStatus.keys():
			value = self.mStatus[name,]
			result = self.writeStatus(name, value, ipaddr, port)
			if result == False: break
		
		return result
		
	###############################################
	@classmethod
	def getChannels(cls): return cls.MAX_CHANNELS

	
