#!/usr/bin/python
# -*- coding: utf-8 -*-

import sys
import array
import socket

from . import constant
from ..num import bitconverter, byteorder


class FastTXBase(object):

	############################################
	def __init__(self, rbcp = None):
		self.__initializing()
		self.setDefaultRBCP(rbcp)

	############################################
	def __del__(self):
		self.disconnectDevice()

	############################################
	def __initializing(self):
		self.mRBCP = None
		self.mSocket = None
		self.mConnected = False
		self.mDeviceIpaddr = None
		self.mLastException = None

	############################################
	def setDefaultRBCP(self, rbcp):
		self.mRBCP = rbcp

	############################################
	def getUsingRBCP(self, rbcp):
		object0 = rbcp if not rbcp is None else self.mRBCP
		return object0

	############################################
	def setTimeout(self, msec):
		result = False
		
		if self.mSocket != None:
			self.mSocket.settimeout((msec / 1000.0))
			result = True
		
		return result

	############################################
	def getTimeout(self):
		msec = 0
		
		if self.mSocket != None:
			msec = self.mSocket.gettimeout(msec)

		return msec

	############################################
	def connectDevice(self, timeoutms, dest_ipaddr, dest_port = constant.FASTTX_TCP_PORT, src_ipaddr = "0.0.0.0", src_port = 0):
		
		result = True

		try:
			sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)

			if timeoutms != None:
				sock.settimeout((timeoutms / 1000.0))

			sock.bind((src_ipaddr, src_port))
			sock.connect((dest_ipaddr, dest_port))

			self.mSocket = sock
			self.mDeviceIpaddr = dest_ipaddr
			self.mConnected = True

		except Exception as ex:
			self.mLastException = ex
			result = False

		return result

	############################################
	def disconnectDevice(self):

		result = False

		if not self.mSocket is None:
			self.mSocket.close()
			result = True

		work = self.mLastException
		self.__initializing()
		self.mLastException = work

		return result

	############################################
	def setBufferSizeTX(self, nbytes): self.__setSocketBufferSize(socket.SO_SNDBUF, nbytes)
	def setBufferSizeRX(self, nbytes): self.__setSocketBufferSize(socket.SO_RCVBUF, nbytes)
	def __setSocketBufferSize(self, optname, nbytes): self.mSocket.setsockopt(socket.SOL_SOCKET, optname, nbytes)
	
	############################################
	def getBufferSizeTX(self): return self.__getSocketBufferSize(socket.SO_SNDBUF)
	def getBufferSizeRX(self): return self.__getSocketBufferSize(socket.SO_RCVBUF)
	def __getSocketBufferSize(self, optname): return self.mSocket.getsockopt(socket.SOL_SOCKET, optname)

	############################################
	def readHistogram(self, regaddr, chn, rxbytes, rbcp = None, dest_port = None):
		
		rxdata = None

		try:
			rbcp0 = self.getUsingRBCP(rbcp)
			result = rbcp0.write16bit(regaddr, chn, self.mDeviceIpaddr, dest_port)

			if result == True:
				rxdata0 = self.__recieve(self.mSocket, rxbytes)
				nbytes = len(rxdata0)
				rxdata = array.array("I")

				nbytes0 = int(nbytes / 4) * 4

				for i in range(0, nbytes0, 4):
					value = bitconverter.toIntU32(rxdata0[i:i+4])
					rxdata.append(value)
				
				if byteorder.isBigmachine() == False:
					rxdata.byteswap()

		except Exception as ex:
			self.mLastException = ex

		return rxdata

	############################################
	def _recieve(self, rxbytes): return self.__recieve(self.mSocket, rxbytes)

	############################################
	@staticmethod
	def __recieve(sock, rxbytes):

		ver = sys.version_info.major	#python version

		rxtext = str()
		rxdata = None
		sumbytes = 0

		##########recieve##########
		if ver == 2:	#version 2.#
			while sumbytes < rxbytes:
				zbytes = rxbytes - sumbytes

				try:
					rxdata0 = sock.recv(zbytes)
				except Exception as ex:
					rxdata0 = None
					#print (ex)
			
				if rxdata0 is None: break

				rxdata1 = bytearray(rxdata0)
				rvbytes = len(rxdata1)
				#print (rvbytes)

				if rvbytes <= 0:
					break

				rxtext += rxdata0
				sumbytes += rvbytes

			if sumbytes > 0:
				rxdata = bytearray(rxtext)
		elif ver >= 3:	#version 3.#
			##########################################
			rxdata1 = bytearray()

			while sumbytes < rxbytes:
				try:
					zbytes = rxbytes - sumbytes
					rxdata0 = sock.recv(zbytes)
				except Exception as ex:
					rxdata0 = None
					#print (ex)
			
				if rxdata0 is None: break

				rvbytes = len(rxdata0)
				#print (rvbytes)

				if rvbytes <= 0:
					break

				rxdata1 += rxdata0
				sumbytes += rvbytes

			if sumbytes > 0:
				rxdata = rxdata1
			##########################################
			
		return rxdata




